@@ -1,10 +1,10 @@
 from abc import ABC
-from dataverk.connectors.abc.base import BaseConnector
+from dataverk.connectors.abc.base import DataverkBase
 
 
-class BucketStorageConnector(BaseConnector, ABC):
+class BucketStorageConnector(DataverkBase, ABC):
 
-    def __init__(self, encrypted=True):
+    def __init__(self):
         super().__init__()
 
     def write(self, data, destination_blob_name: str, fmt: str, metadata: dict={}):
