@@ -7,6 +7,7 @@ import re
 from urllib3.util import url
 from os import environ
 
+from data_catalog_dcat_validator.models.dataset import DatasetModel
 from dataverk.exceptions.dataverk_exceptions import EnvironmentVariableNotSet
 from dataverk.utils import validators, file_functions
 from collections.abc import Mapping, Sequence
@@ -21,6 +22,7 @@ class Datapackage:
     def __init__(self, metadata: Mapping):
         self._resources = {}
         self.views = []
+        self._validate_metadata(metadata)
         self._datapackage_metadata = self._create_datapackage(dict(metadata))
 
     def _create_datapackage(self, metadata):
@@ -59,6 +61,12 @@ class Datapackage:
         metadata["datasets"] = {}
         return metadata
 
+    @staticmethod
+    def _validate_metadata(metadata: Mapping):
+        validator = DatasetModel(metadata)
+        validator.validate()
+        validator.error_report()
+
     @property
     def datapackage_metadata(self):
         return copy.deepcopy(self._datapackage_metadata)
